/*
     **********************************************************************
     *  Program     : ADBLOCK.C                                           *
     *  Description : Demo program for PCL-711 pacer trigger A/D          *
     *                conversion on a block of channels with interrupt    *
     *                data transfer.                                      *
     *  Revision    : 1.00                                                *
     *  Date        : 6/03/92                       Advantech Co., Ltd.   *
     **********************************************************************
*/

#include <stdio.h>
#include <conio.h>
#include <stdlib.h>
#include <dos.h>

extern pcl711(int, unsigned int *);
unsigned int param[60];       /* If two boards installed, need to declare
				 the second parameter array                */
unsigned int data[100];       /* Conversion data buffer                    */
unsigned int far * dat;
main()
{
unsigned int i;
float        DataBuf;

       dat = data;
       clrscr();       
       param[0]  = 0;            /* Board number                           */
       param[1]  = 0x220;        /* Base I/O address                       */
       param[4]  = 2;            /* IRQ level   : IRQ2                     */
       param[5]  = 50;           /* Pacer rate = 2M / (50 * 100) = 400 Hz  */
       param[6]  = 100;
       param[7]  = 0;            /* Trigger mode, 0 : pacer trigger        */
       param[8]  = 0;            /* Non-cyclic                             */
       param[10] = FP_OFF(dat);  /* Offset of A/D data buffer A            */
       param[11] = FP_SEG(dat);  /* Segment of A/D data buffer A           */
       param[12] = 0;            /* Data buffer B address, if not used,    */
       param[13] = 0;            /* must set to 0.                         */
       param[14] = 50;           /* A/D conversion number                  */
       param[15] = 0;            /* A/D conversion start channel           */
       param[16] = 7;            /* A/D conversion stop channel            */
       param[17] = 0;            /* Overall gain code, 0 : +/- 5V          */

       /* param[18] = FP_OFF(gain_array);
          param[19] = FP_SEG(gain_array);  */

       /* param[45] : Error code
          param[46] : Return value 0
          param[47] : Return value 1 */

       pcl711(3, param);         /* Func 3 : Hardware initialization       */
       if (param[45] != 0) {
            printf("\nDRIVER INITIALIZATION FAILED !");
            exit(1);
            }

       pcl711(100, param);       /* Func 100 : A/D initialization          */
       if (param[45] != 0) {
            printf("\nA/D INITIALIZATION FAILED !");
            exit(1);
            }

       /* Block channel scan function 105 is very similar to function 9.
          The only difference is block channel scan function 105 scans
          all input channels (specified by param[15] and param[16])
          on each trigger pulse, and the function 9 scans one channel
          on each trigger pulse. */

       pcl711(105, param);       /* Func 105 : Pacer trigger A/D conversion  */
       if (param[45] != 0) {     /* with interrupt data transfer             */
            printf("\n A/D INTERRUPT BLOCK DATA TRANSFER FAILED !");
	    exit(1);
	    }
       do {
	    pcl711(106, param);           /* Func 106:Check interrupt status  */
       }while((param[46] & 1) != 0);      /* 0 : not active, 1 : active       */

       for (i = 0; i < param[14]; i++)    /* Display data                    */
	 {
	    DataBuf = data[i] & 0xFFF;
	    DataBuf =( (5 - (-5)) * DataBuf / 4096) + (-5);
	    /*
	       (5 - (-5)) : A/D input range (-5V  to  5V)
	       4096       : Full scale 12 bit A/D data
	       DataBuf    : A/D input data
	       (-5)       : A/D input range "-5" V
	    */
	    printf("\ndata[%3d] = % 1.2f V ", i, DataBuf);

	  }
}
